==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/salt2model.h <==
// -*- C++ -*-
// 
// 
// 
//. 
#ifndef SALT2MODEL_H
#define SALT2MODEL_H

//#define WITH_HOST_EXTINCTION
//#define WITH_UV_FIT
//#define ALLOW_WARPING


#include <string>
#include <map>

#include "param.h"
#include "model2fit.h"
#include "measureddata.h"
#include "salt2extinction.h"

#ifdef NEW_ERRORS
#include "covariancemodel.h"
#endif

class CovarianceModel;
class GalaxyTemplate;
class Salt2Model : public Model2Fit {

private:
  
#ifdef POSTCORRECTION
  double post_correction(const double& restframe_wavelength)  const;
  Vect PostCorrectionVector;
#endif

  
  bool forcepositiveEBV;
  double GetMag(const Filter &filer, double phase, const string &magsys);
  
  //! reference wavelength for filter selection
  double ReferenceWavelength;
  
  //! parameters of this model
  LcParam *pDayMax;
  LcParam *pRedshift;
#ifdef WITH_HOST_EXTINCTION
  LcParam *pTau;
  LcParam *pRv;
#endif
#ifdef WITH_UV_FIT
  LcParam *pUV;
#endif
  LcParam *pColor;
  
  //! one set of calibration parameters per spectrum
  map < string , vector<LcParam*> > calibparams;

#ifdef ALLOW_WARPING 
  //! warping params (def=0)
  vector<LcParam*> pW;
  double warping_constant_0;
  double warping_constant_1; 
#endif

  //! the coordinates
  vector<LcParam*> pX;
  
  //! the principal components
  vector<Grid2DFunction> F;
  
  //! error of model
  //vector<Grid2DFunction> photometric_errors;
  
  Grid2DFunction photometric_relative_variance_0;
  Grid2DFunction photometric_relative_variance_1;
  Grid2DFunction photometric_relative_covariance_01;
  Grid2DFunction spectroscopic_variance_0;
  Grid2DFunction spectroscopic_variance_1;
  Grid2DFunction spectroscopic_covariance_01;
  
  Grid2DFunction photometric_errors_scaling;
  Grid2DFunction spectroscopic_errors_scaling;
  
  int ReadComponents(const string& dir);

  Salt2ExtinctionLaw extinction_law;
  
  
  GalaxyTemplate *galaxy_template;
  LcParam *pGalaxyContam;
  LcParam *pOnlyGalaxyNorm;
  LcParam *pGalaxyType;
  
  // Vect KVect; // polynomial of kcorrection errors

  bool with_lc_error_scaling;
  bool with_spec_error_scaling;
 
 
#ifdef NEW_ERRORS
  CovarianceModel covariance_model;
#else
  General1DFunction Ksigma; // function of wavelength
#endif
 
public:
  Salt2Model();
  virtual ~Salt2Model() {};
  
  const Salt2ExtinctionLaw& GetExtinctionLaw() const { return extinction_law;};
  
  virtual double Flux(const Filter* filter,
		      const double observerday) const;
  
  double RestFrameFlux(const double lambda, 
		       const double observerday) const;
  
  virtual double SpectrumFlux(const double observerlambda, 
			      const double observerday) const;
		     
  virtual double GalaxySpectrumFlux(const double observerlambda, bool only_galaxy=false); 
  
  double SpectrumCalibration(const double observerlambda, 
			     const MeasuredSpectrum& spectrum);
  
  virtual string ModelName() const { return "Salt2Model"; }
  
  void ReadParams(const string& filename);  
  
  virtual bool CanComputeFluxFor(const Filter &observerfilter,bool quiet=false) const;
    
  //virtual void KeepOnlyNBands(int n, MeasuredData* data);
  

  void FitGalaxySpectrum(const MeasuredSpectrum* spec = 0);
  virtual bool CanFitGalaxySpectrum() const {return galaxy_template!=0;};
  
  /*
  virtual double GetRestFrameMagAtPhase(const Filter& filter,
					double phase,
					string const& magsys="VEGA");
  
  virtual LcParam GetMagAtPhase(const Filter& filter,
				double phase,
				string const& magsys="VEGA");
  
  */
  
  virtual void InitParams(const MeasuredData* data);
  
  virtual  vector<LcParam*> InitCalibrationParams(const MeasuredSpectrum *spec, int n_recalibration_params = 1);
  
  double GetPhase(double day) const;
  
  void Update();
  
#ifdef NEW_ERRORS
  virtual double ModelRelativeCovariance(const Filter* filter,
					 const double observerday1,
					 const double observerday2);
#else
  //! flux to be compared to the data
  virtual double ModelKError(const Filter* filter);
#endif
  

  //! flux to be compared to the data
  virtual double ModelRelativeError(const Filter* filter,
		      const double observerday, bool with_scaling=false);
  
  
  
  virtual double SpectrumModelError(const double observerlambda,  
				    const double observerday,
				    bool with_scaling=false);  
  

  const vector<LcParam*>* GetCalibParams(const string& spectrum_name) const;
  vector<LcParam*>* GetCalibParams(const string& spectrum_name);
  
#ifdef ALLOW_WARPING
  void SetNumberOfWarpingParams(size_t n);
  int NumberOfWarpingParams() const {return pW.size();};
#endif
};


#endif /* SALT2MODEL__H */

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/salt2model.h <==
// -*- C++ -*-
// 
// 
// 
//. 
#ifndef SALT2MODEL_H
#define SALT2MODEL_H

//#define WITH_HOST_EXTINCTION
//#define WITH_UV_FIT
//#define ALLOW_WARPING
//#define WITH_COLOR_SMEARING

#include <string>
#include <map>

#include "param.h"
#include "model2fit.h"
#include "measureddata.h"
#include "salt2extinction.h"

#ifdef NEW_ERRORS
#include "covariancemodel.h"
#endif



class CovarianceModel;
class GalaxyTemplate;
class Salt2Model : public Model2Fit {

public:
  
#ifdef WITH_COLOR_SMEARING
  // correction as a function of wavelength in magnitude performed with sin function
  std::vector<string> color_smearing_param_name;
  std::vector<double> color_smearing_lambda;
  std::vector<double*> color_smearing_dmag; // pointing to the associated param->val 
#endif
private:
  
  bool forcepositiveEBV;
  double GetMag(const Filter &filer, double phase, const std::string &magsys);
  
  //! reference wavelength for filter selection
  double ReferenceWavelength;
  
  //! parameters of this model
  LcParam *pDayMax;
  LcParam *pRedshift;
#ifdef WITH_HOST_EXTINCTION
  LcParam *pTau;
  LcParam *pRv;
#endif
#ifdef WITH_UV_FIT
  LcParam *pUV;
#endif
  LcParam *pColor;
  
  //! one set of calibration parameters per spectrum
  std::map < std::string , std::vector<LcParam*> > calibparams;

#ifdef ALLOW_WARPING 
  //! warping params (def=0)
  std::vector<LcParam*> pW;
  double warping_constant_0;
  double warping_constant_1; 
#endif

  //! the coordinates
  std::vector<LcParam*> pX;
  
  //! the principal components
  std::vector<Grid2DFunction> F;
  
  //! error of model
  //vector<Grid2DFunction> photometric_errors;
  
  Grid2DFunction photometric_relative_variance_0;
  Grid2DFunction photometric_relative_variance_1;
  Grid2DFunction photometric_relative_covariance_01;
  Grid2DFunction spectroscopic_variance_0;
  Grid2DFunction spectroscopic_variance_1;
  Grid2DFunction spectroscopic_covariance_01;
  
  Grid2DFunction photometric_errors_scaling;
  Grid2DFunction spectroscopic_errors_scaling;
  
  int ReadComponents(const std::string& dir);

  Salt2ExtinctionLaw extinction_law;
  
  
  GalaxyTemplate *galaxy_template;
  LcParam *pGalaxyContam;
  LcParam *pOnlyGalaxyNorm;
  LcParam *pGalaxyType;
  
  // Vect KVect; // polynomial of kcorrection errors

  bool with_lc_error_scaling;
  bool with_spec_error_scaling;
 
 
#ifdef NEW_ERRORS
  CovarianceModel covariance_model;
#else
  General1DFunction Ksigma; // function of wavelength
#endif
 
public:
  Salt2Model(const std::string &salt2_data_dir="");
  virtual ~Salt2Model() {};

#ifndef NEW_ERRORS
  const General1DFunction& GetKsigma() const { return Ksigma;};
#endif
  
  const Salt2ExtinctionLaw& GetExtinctionLaw() const { return extinction_law;};
  
  virtual double Flux(const Filter* filter,
		      const double observerday) const;
  
  double RestFrameFlux(const double lambda, 
		       const double observerday) const;
  
  virtual double SpectrumFlux(const double observerlambda, 
			      const double observerday) const;
		     
  virtual double GalaxySpectrumFlux(const double observerlambda, bool only_galaxy=false); 
  
  double SpectrumCalibration(const double observerlambda, 
			     const MeasuredSpectrum& spectrum);
  
  virtual std::string ModelName() const { return "Salt2Model"; }
  
  void ReadParams(const std::string& filename);  
  
  virtual bool CanComputeFluxFor(const Filter &observerfilter,bool quiet=false) const;
    
  //virtual void KeepOnlyNBands(int n, MeasuredData* data);
  

  void FitGalaxySpectrum(const MeasuredSpectrum* spec = 0);
  virtual bool CanFitGalaxySpectrum() const {return galaxy_template!=0;};
  
  /*
  virtual double GetRestFrameMagAtPhase(const Filter& filter,
					double phase,
					string const& magsys="VEGA");
  
  virtual LcParam GetMagAtPhase(const Filter& filter,
				double phase,
				string const& magsys="VEGA");
  
  */
  
  virtual void InitParams(const MeasuredData* data);
  
  virtual  std::vector<LcParam*> InitCalibrationParams(const MeasuredSpectrum *spec, int n_recalibration_params = 1);
  
  double GetPhase(double day) const;
  
  void Update();
  
#ifdef NEW_ERRORS
  virtual double ModelRelativeCovariance(const Filter* filter,
					 const double observerday1,
					 const double observerday2);
#else
  //! flux to be compared to the data
  virtual double ModelKError(const Filter* filter);
#endif
  

  //! flux to be compared to the data
  virtual double ModelRelativeError(const Filter* filter,
		      const double observerday, bool with_scaling=false);
  
  
  
  virtual double SpectrumModelError(const double observerlambda,  
				    const double observerday,
				    bool with_scaling=false);  
  

  const std::vector<LcParam*>* GetCalibParams(const std::string& spectrum_name) const;
  std::vector<LcParam*>* GetCalibParams(const std::string& spectrum_name);

  
#ifdef ALLOW_WARPING
  void SetNumberOfWarpingParams(std::size_t n);
  int NumberOfWarpingParams() const {return pW.size();};
#endif
};


#endif /* SALT2MODEL__H */
